import React, { useState, useEffect, useMemo } from "react";
import Image from "next/image";
import { Box, Container, Flex, Stack, Text, Button, Link, } from "@chakra-ui/react";
import { DOCS_URL, MARKETPLACE_URL } from "../../constants";
import TextTransition, { presets } from "react-text-transition";
const callouts = [
    {
        image: "/easyToUse.png",
        heading: "Easy to Use",
        body: "Strata provides SDKs to launch Tokens in an instant. No Rust or Solana experience needed!",
        alt: "launch token solana",
    },
    {
        image: "/freeAndOpen.png",
        heading: "Free and Open",
        body: "Strata is free to use and Open Source. Launch your token without someone else taking a cut!",
        alt: "solana token launch",
    },
    {
        image: "/buildWithReact.png",
        heading: "Build Quickly with React",
        body: "Strata comes with hooks and helpers to make coding using React a breeze.",
        alt: "solana react",
    },
];
export const Hero = () => {
    const options = useMemo(() => [
        "Social Token",
        "GameFi Token",
        "DAO Token",
        "SubDAO Token",
        "Community Token",
    ], []);
    const [currentOptionIndex, setCurrentOptionIndex] = useState(0);
    useEffect(() => {
        const timer = setTimeout(() => {
            setCurrentOptionIndex(currentOptionIndex == options.length - 1 ? 0 : currentOptionIndex + 1);
        }, 3000);
        return () => clearTimeout(timer);
    }, [currentOptionIndex, setCurrentOptionIndex, options]);
    return (React.createElement(Box, { w: "full", bg: "#191C2A", color: "white" },
        React.createElement(Container, { maxW: "container.lg" },
            React.createElement(Flex, { align: "center", justify: {
                    base: "center",
                    md: "space-between",
                    xl: "space-between",
                }, direction: { base: "column-reverse", md: "row" }, wrap: "nowrap", py: 20 },
                React.createElement(Stack, { spacing: 6, w: { base: "80%", md: "40%" }, align: ["center", "center", "flex-start", "flex-start"] },
                    React.createElement(Box, { fontSize: "4xl", fontWeight: "light", lineHeight: "normal", color: "white", textAlign: ["center", "center", "left", "left"] },
                        "The fastest way to",
                        React.createElement("br", null),
                        "launch and grow your",
                        React.createElement("br", null),
                        React.createElement(TextTransition, { className: "gradient", inline: true, style: {
                                color: "transparent",
                                fontWeight: "bold",
                            }, text: options[currentOptionIndex], springConfig: presets.default })),
                    React.createElement(Text, { fontSize: "md", color: "white", fontWeight: "normal", lineHeight: 1.5, textAlign: ["center", "center", "left", "left"] }, "Strata Protocol is an open-source protocol to launch tokens around a person, project, idea, or collective on Solana."),
                    React.createElement(Stack, { direction: "row", gap: 2, w: "full" },
                        React.createElement(Button, { isFullWidth: true, colorScheme: "orange", as: Link, href: `${MARKETPLACE_URL}/launchpad`, _hover: {
                                textDecoration: "none",
                            }, isExternal: true }, "Launch a Token"),
                        React.createElement(Button, { isFullWidth: true, colorScheme: "orange", variant: "outline", textColor: "white", borderColor: "orange.500", _hover: { bg: "orange.500", textDecoration: "none" }, as: Link, href: DOCS_URL }, "Developer Docs"))),
                React.createElement(Box, null,
                    React.createElement(Image, { src: "/hero.png", alt: "solana social tokens", height: "488px", width: "714px" }))),
            React.createElement(Stack, { gap: 4, direction: ["column", "column", "row"], width: { base: "70%", md: "100%" }, margin: "0 auto", pb: 20 }, callouts.map((callout, index) => (React.createElement(Box, { key: callout.heading, bgGradient: "linear(to-b, orange.400, yellow.400);", p: "2px", rounded: "md", w: "full", color: "white" },
                React.createElement(Box, { h: "full", w: "full", bg: "gray.900", p: 6, rounded: "md" },
                    React.createElement(Stack, { gap: 1 },
                        React.createElement(Box, null,
                            React.createElement(Image, { src: callout.image, alt: callout.alt, width: "64px", height: "64px" })),
                        React.createElement(Text, { fontSize: "lg", fontWeight: "bold" }, callout.heading),
                        React.createElement(Text, { fontSize: "xs" }, callout.body))))))))));
};
//# sourceMappingURL=Hero.js.map